@@ -475,31 +475,31 @@ class Search:
 
         # Combo boxes
         self.filter_include_combobox = ComboBox(
-            container=self.filter_include_container, has_entry=True, enable_arrow_keys=False,
+            container=self.filter_include_container, has_entry=True,
             entry=self.filter_include_entry, item_selected_callback=self.on_refilter)
 
         self.filter_exclude_combobox = ComboBox(
-            container=self.filter_exclude_container, has_entry=True, enable_arrow_keys=False,
+            container=self.filter_exclude_container, has_entry=True,
             entry=self.filter_exclude_entry, item_selected_callback=self.on_refilter)
 
         self.filter_file_type_combobox = ComboBox(
-            container=self.filter_file_type_container, has_entry=True, enable_arrow_keys=False,
+            container=self.filter_file_type_container, has_entry=True,
             entry=self.filter_file_type_entry, item_selected_callback=self.on_refilter)
 
         self.filter_file_size_combobox = ComboBox(
-            container=self.filter_file_size_container, has_entry=True, enable_arrow_keys=False,
+            container=self.filter_file_size_container, has_entry=True,
             entry=self.filter_file_size_entry, item_selected_callback=self.on_refilter)
 
         self.filter_bitrate_combobox = ComboBox(
-            container=self.filter_bitrate_container, has_entry=True, enable_arrow_keys=False,
+            container=self.filter_bitrate_container, has_entry=True,
             entry=self.filter_bitrate_entry, item_selected_callback=self.on_refilter)
 
         self.filter_length_combobox = ComboBox(
-            container=self.filter_length_container, has_entry=True, enable_arrow_keys=False,
+            container=self.filter_length_container, has_entry=True,
             entry=self.filter_length_entry, item_selected_callback=self.on_refilter)
 
         self.filter_country_combobox = ComboBox(
-            container=self.filter_country_container, has_entry=True, enable_arrow_keys=False,
+            container=self.filter_country_container, has_entry=True,
             entry=self.filter_country_entry, item_selected_callback=self.on_refilter)
 
         self.tree_view = TreeView(
@@ -672,6 +672,9 @@ class Search:
             buffer = combobox.entry.get_buffer()
             buffer.connect_after("deleted-text", self.on_filter_entry_deleted_text)
 
+            if GTK_API_VERSION == 3:
+                add_css_class(combobox.dropdown, "dropdown-scrollbar")
+
         self.filters_button.set_active(config.sections["searches"]["filters_visible"])
         self.populate_filter_history()
         self.populate_default_filters()
@@ -1731,7 +1734,7 @@ class Search:
             self.window.application.lookup_action("wishlist").activate()
             return
 
-        self.window.lookup_action("search-mode").change_state(GLib.Variant("s", self.mode))
+        self.window.lookup_action("search-mode").change_state(GLib.Variant.new_string(self.mode))
 
         if self.mode == "room":
             self.window.room_search_entry.set_text(self.room)
