@@ -1,4 +1,4 @@
-# COPYRIGHT (C) 2020-2023 Nicotine+ Contributors
+# COPYRIGHT (C) 2020-2024 Nicotine+ Contributors
 #
 # GNU GENERAL PUBLIC LICENSE
 #    Version 3, 29 June 2007
@@ -17,6 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
+import sys
 
 from gi.repository import Gdk
 from gi.repository import GLib
@@ -25,7 +26,7 @@ from gi.repository import Gtk
 from pynicotine.config import config
 from pynicotine.gtkgui.application import GTK_API_VERSION
 from pynicotine.gtkgui.widgets.accelerator import Accelerator
-from pynicotine.gtkgui.widgets.textentry import ComboBox
+from pynicotine.gtkgui.widgets.combobox import ComboBox
 from pynicotine.gtkgui.widgets.textview import TextView
 from pynicotine.gtkgui.widgets.theme import add_css_class
 from pynicotine.gtkgui.widgets.window import Window
@@ -173,6 +174,12 @@ class Dialog(Window):
 
         # Hide the dialog
         self.widget.set_visible(False)
+
+        # "Soft-delete" the dialog. This is necessary to prevent the dialog from
+        # appearing in window peek on Windows
+        if sys.platform == "win32" and self.widget.get_titlebar() is None:
+            self.widget.unrealize()
+
         return True
 
     def _set_dialog_properties(self):
@@ -236,6 +243,18 @@ class Dialog(Window):
         self.widget.set_modal(self.modal and self.parent.is_visible())
         present_callback()
 
+    def set_show_title_buttons(self, visible):
+
+        header_bar = self.widget.get_titlebar()
+
+        if header_bar is None:
+            return
+
+        if GTK_API_VERSION >= 4:
+            header_bar.set_show_title_buttons(visible)    # pylint: disable=no-member
+        else:
+            header_bar.set_show_close_button(visible)     # pylint: disable=no-member
+
     def present(self):
 
         if self not in Window.active_dialogs:
@@ -262,9 +281,9 @@ class MessageDialog(Window):
     def __init__(self, parent, title, message, callback=None, callback_data=None, long_message=None,
                  buttons=None, destructive_response_id=None):
 
-        # Prioritize modal non-message dialogs as parent
+        # Prioritize non-message dialogs as parent
         for active_dialog in reversed(Window.active_dialogs):
-            if isinstance(active_dialog, Dialog) and active_dialog.modal:
+            if isinstance(active_dialog, Dialog):
                 parent = active_dialog
                 break
 
@@ -311,7 +330,7 @@ class MessageDialog(Window):
             add_css_class(widget, css_class)
 
         header_bar = Gtk.Box(height_request=16, visible=True)
-        box = Gtk.Box(margin_start=30, margin_end=30, spacing=30, visible=True)
+        box = Gtk.Box(margin_start=24, margin_end=24, visible=True)
         message_area = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=10, hexpand=True, visible=True)
         action_box = Gtk.Box(visible=True)
         action_area = Gtk.Box(hexpand=True, homogeneous=True, visible=True)
@@ -333,7 +352,7 @@ class MessageDialog(Window):
             widget.set_titlebar(header_bar_handle)
             widget.connect("close-request", self._on_close_request)
 
-            internal_vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=20, visible=True)
+            internal_vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, visible=True)
 
             vbox.append(internal_vbox)                                # pylint: disable=no-member
             vbox.append(action_box)                                   # pylint: disable=no-member
@@ -382,6 +401,9 @@ class MessageDialog(Window):
                     button.set_can_default(True)       # pylint: disable=no-member
                     widget.set_default(button)         # pylint: disable=no-member
 
+                if response_type == "ok":
+                    add_css_class(button, "suggested-action")
+
                 self.message_label.set_mnemonic_widget(button)
                 self.default_focus_widget = button
 
@@ -425,8 +447,8 @@ class MessageDialog(Window):
         if self.callback and response_type != "cancel":
             self.callback(self, response_type, self.callback_data)
 
-        # Check if the dialog was already closed in the callback
-        if self in Window.active_dialogs:
+        # "Run in Background" response already closes all dialogs
+        if response_type != "run_background":
             self.close()
 
     def _finish_present(self, present_callback):
@@ -512,7 +534,7 @@ class EntryDialog(OptionDialog):
 
     def _add_combobox(self, items, has_entry=True, visibility=True, activates_default=True):
 
-        combobox = ComboBox(container=self.entry_container, has_entry=has_entry)
+        combobox = ComboBox(container=self.entry_container, has_entry=has_entry, items=items)
 
         if has_entry:
             entry = combobox.entry
@@ -520,14 +542,6 @@ class EntryDialog(OptionDialog):
             entry.set_width_chars(45)
             entry.set_visibility(visibility)
 
-        if items is not None:
-            combobox.freeze()
-
-            for item in items:
-                combobox.append(item)
-
-            combobox.unfreeze()
-
         if self.entry_combobox is None:
             self.message_label.set_mnemonic_widget(entry if has_entry else combobox.widget)
 
